@@ -1,7 +1,5 @@
 package Class::Meta;
 
-# $Id: Meta.pm 3937 2008-05-22 03:04:22Z david $
-
 =head1 NAME
 
 Class::Meta - Class automation, introspection, and data validation
@@ -46,12 +44,14 @@ Generate a class:
           default => undef,
       );
 
-     # Add a custom method.
+      # Add a custom method.
       $cm->add_method(
           name => 'chk_pass',
           view => 'PUBLIC',
           code => sub { ... },
       );
+
+      $cm->build;
   }
 
   sub chck_pass { ... }
@@ -69,10 +69,10 @@ recommended!):
       has  uuid => (
         authz    => 'READ',
         required => 1,
-        deafult  => sub { Data::UUID->new->create_str },
+        deafault => sub { Data::UUID->new->create_str },
       );
-      has name => ( rquired => 1         );
-      has age  => ( is      => 'integer' );
+      has name => ( required => 1         );
+      has age  => ( is       => 'integer' );
       method chk_pass => sub { ... }
   };
 
@@ -143,7 +143,7 @@ notes here, as well. Or if you're just a masochist and want to use the
 Class::Meta interface itself, well, read on!
 
 I recommend that you create your Class::Meta classes in a C<BEGIN> block.
-Although this is not strictly necessary, it helps to ensure that the classes
+Although this is not strictly necessary, it helps ensure that the classes
 you're building are completely constructed and ready to go by the time
 compilation has completed. Creating classes with Class::Meta is easy, using
 the Class::Meta object oriented interface. Here is an example of a very simple
@@ -748,7 +748,7 @@ use Class::Meta::Method;
 ##############################################################################
 # Package Globals                                                            #
 ##############################################################################
-our $VERSION = '0.63';
+our $VERSION = '0.66';
 
 ##############################################################################
 # Private Package Globals
@@ -1350,16 +1350,17 @@ may not be easy.
 
 =head1 SUPPORT
 
-This module is stored in an open repository at the following address:
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/class-meta/>. Feel free to fork and
+contribute!
 
-L<https://svn.kineticode.com/Class-Meta/trunk/>
-
-Patches against Class::Meta are welcome. Please send bug reports to
-<bug-class-meta@rt.cpan.org>.
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
+L<bug-Class-Meta@rt.cpan.org|mailto:bug-Class-Meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -1430,7 +1431,7 @@ Class::MOP.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2008, David Wheeler. Some Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
