@@ -1,7 +1,5 @@
 package Class::Meta::Type;
 
-# $Id: Type.pm 2873 2006-05-28 20:03:44Z theory $
-
 =head1 NAME
 
 Class::Meta::Type - Data type validation and accessor building.
@@ -14,13 +12,16 @@ Class::Meta::Type - Data type validation and accessor building.
   use Class::Meta::Type;
   use IO::Socket;
 
-  my $type = Class::Meta::Type->add( key  => 'io_socket',
-                                     desc => 'IO::Socket object',
-                                     name => 'IO::Socket Object' );
+  my $type = Class::Meta::Type->add(
+      key  => 'io_socket',
+      desc => 'IO::Socket object',
+      name => 'IO::Socket Object'
+  );
 
 =head1 DESCRIPTION
 
-This class stores the various data types used by C<Class::Meta>. It manages
+This class stores the various data types us
+ed by C<Class::Meta>. It manages
 all aspects of data type validation and method creation. New data types can be
 added to Class::Meta::Type by means of the C<add()> constructor. This is
 useful for creating custom types for your Class::Meta-built classes.
@@ -41,7 +42,7 @@ use strict;
 ##############################################################################
 # Package Globals                                                            #
 ##############################################################################
-our $VERSION = "0.53";
+our $VERSION = '0.66';
 
 ##############################################################################
 # Private Package Globals                                                    #
@@ -59,8 +60,9 @@ my $class_validation_generator = sub {
         sub {
             return unless defined $_[0];
             UNIVERSAL::isa($_[0], $pkg)
-              or $_[2]->class->handle_error("Value '$_[0]' is not a valid "
-                                           . "$type");
+              or $_[2]->class->handle_error(
+                  "Value '$_[0]' is not a valid $type"
+              );
             }
     ];
 };
@@ -150,8 +152,8 @@ types.
 
     sub new {
         my $class = shift;
-        my $key = lc shift
-          || Class::Meta->handle_error("Type argument required");
+        Class::Meta->handle_error('Type argument required') unless $_[0];
+        my $key = lc shift;
         unless (exists $types{$key}) {
             # See if there's a Class::Meta class defined for this key.
             my $cmc = Class::Meta->for_key($key)
@@ -171,9 +173,11 @@ types.
 
 =head2 add
 
-  my $type = Class::Meta::Type->add( key  => 'io_socket',
-                                     name => 'IO::Socket Object',
-                                     desc => 'IO::Socket object' );
+  my $type = Class::Meta::Type->add(
+      key  => 'io_socket',
+      name => 'IO::Socket Object',
+      desc => 'IO::Socket object'
+  );
 
 Creates a new data type definition and stores it for future use. Use this
 constructor to add new data types to meet the needs of your class. The named
@@ -183,9 +187,9 @@ parameter arguments are:
 
 =item key
 
-Required. The key with which the data type can be looked up in the future via a
-call to C<new()>. Note that the key will be used case-insensitively, so "foo",
-"Foo", and "FOO" are equivalent, and the key must be unique.
+Required. The key with which the data type can be looked up in the future via
+a call to C<new()>. Note that the key will be used case-insensitively, so
+"foo", "Foo", and "FOO" are equivalent, and the key must be unique.
 
 =item name
 
@@ -203,9 +207,9 @@ The check parameter can be specified in any of the following ways:
 
 As a code reference. When Class::Meta executes this code reference, it will
 pass in the value to check, the object for which the attribute will be set,
-and the Class::Meta::Attribute object describing the attribute. If the attribute
-is a class attribute, then the second argument will not be an object, but a
-hash reference with two keys:
+and the Class::Meta::Attribute object describing the attribute. If the
+attribute is a class attribute, then the second argument will not be an
+object, but a hash reference with two keys:
 
 =over 8
 
@@ -285,9 +289,9 @@ course.
 =item "affordance"
 
 The string 'default' uses Class::Meta::Type's affordance accessor building
-code, provided by Class::Meta::AccessorBuilder::Affordance. Affordance accessors
-provide two accessors for an attribute, a C<get_*> accessor and a C<set_*>
-mutator. See
+code, provided by Class::Meta::AccessorBuilder::Affordance. Affordance
+accessors provide two accessors for an attribute, a C<get_*> accessor and a
+C<set_*> mutator. See
 L<Class::Meta::AccessorBuilder::Affordance|Class::Meta::AccessorBuilder::Affordance>
 for more information.
 
@@ -306,8 +310,8 @@ for more information.
 Pass in the name of a package that contains the functions C<build()>,
 C<build_attr_get()>, and C<build_attr_set()>. These functions will be used to
 create the necessary accessors for an attribute. See L<Custom Accessor
-Building|"Custom Accessor Building"> for details on creating your own
-accessor builders.
+Building|"Custom Accessor Building"> for details on creating your own accessor
+builders.
 
 =back
 
@@ -318,10 +322,10 @@ accessor builders.
     sub add {
         my $pkg = shift;
         # Make sure we can process the parameters.
-        Class::Meta->handle_error("Odd number of parameters in "
-                                            . "call to new() when named "
-                                            . "parameters were expected")
-            if @_ % 2;
+        Class::Meta->handle_error(
+            'Odd number of parameters in call to new() when named '
+                . 'parameters were expected'
+            ) if @_ % 2;
 
         my %params = @_;
 
@@ -601,20 +605,24 @@ and you're happy with the accessors that Class::Meta will create for you. For
 example, if you needed a data type for a DateTime object, you can set it
 up--complete with validation of the data type, like this:
 
-  my $type = Class::Meta::Type->add( key   => 'datetime',
-                                     check => 'DateTime',
-                                     desc  => 'DateTime object',
-                                     name  => 'DateTime Object' );
+  my $type = Class::Meta::Type->add(
+      key   => 'datetime',
+      check => 'DateTime',
+      desc  => 'DateTime object',
+      name  => 'DateTime Object'
+  );
 
 From then on, you can create attributes of the type "datetime" without any
 further work. If you wanted to use affordance accessors, you'd simply
 add the requisite C<builder> attribute:
 
-  my $type = Class::Meta::Type->add( key     => 'datetime',
-                                     check   => 'DateTime',
-                                     builder => 'affordance',
-                                     desc    => 'DateTime object',
-                                     name    => 'DateTime Object' );
+  my $type = Class::Meta::Type->add(
+      key     => 'datetime',
+      check   => 'DateTime',
+      builder => 'affordance',
+      desc    => 'DateTime object',
+      name    => 'DateTime Object'
+  );
 
 The same goes for using semi-affordance accessors.
 
@@ -630,10 +638,12 @@ like this:
       die "Value is not a number" unless $value =~ /^[1..5]$/;
   };
 
-  my $type = Class::Meta::Type->add( key   => 'range',
-                                     check => $range_chk,
-                                     desc  => 'Pick a number between 1 and 5',
-                                     name  => 'Range (1-5)' );
+  my $type = Class::Meta::Type->add(
+      key   => 'range',
+      check => $range_chk,
+      desc  => 'Pick a number between 1 and 5',
+      name  => 'Range (1-5)'
+  );
 
 Of course, the above value validator will throw an exception with the
 line number from which C<die> is called. Even better is to use L<Carp|Carp>
@@ -657,7 +667,7 @@ Class::Meta also allows you to craft your own accessors. Perhaps you'd prefer
 to use a StudlyCaps affordance accessor standard. In that case, you'll need to
 create your own module that builds accessors. I recommend that you study
 L<Class::Meta::AccessorBuilder|Class::Meta::AccessorBuilder> and
-LClass::Meta::AccessorBuilder::Affordance|Class::Meta::AccessorBuilder::Affordance>
+L<Class::Meta::AccessorBuilder::Affordance|Class::Meta::AccessorBuilder::Affordance>
 before taking on creating your own.
 
 Custom accessor building modules must have three functions.
@@ -685,11 +695,12 @@ The name of the class into which the accessors are to be installed.
 A Class::Meta::Attribute object representing the attribute for which accessors
 are to be created. Use it to determine what types of accessors to create
 (read-only, write-only, or read/write, class or object), and to add checks for
-requiredness and accessibility (if the attribute is private or protected).
+required constraints and accessibility (if the attribute is private, trusted,
+or protected).
 
 =item C<$create>
 
-The value of the C<create> paramter passed to Class::Meta::Attribute when the
+The value of the C<create> parameter passed to Class::Meta::Attribute when the
 attribute object was created. Use this argument to determine what type of
 accessor(s) to create. See L<Class::Meta::Attribute|Class::Meta::Attribute>
 for the possible values for this argument.
@@ -716,14 +727,19 @@ C<set()> methods to get and set attribute values. Again, see
 L<Class::Meta::AccessorBuilder|Class::Meta::AccessorBuilder> for examples
 before creating your own.
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please send bug reports to <bug-class-meta@rt.cpan.org> or report them via the
-CPAN Request Tracker at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Meta>.
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/class-meta/>. Feel free to fork and
+contribute!
+
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
+L<bug-Class-Meta@rt.cpan.org|mailto:bug-Class-Meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -771,14 +787,14 @@ Affordance accessors--that is, explicit and independent get and set accessors.
 
 =item L<Class::Meta::AccessorBuilder::SemiAffordance|Class::Meta::AccessorBuilder::SemiAffordance>
 
-Semi-ffordance accessors--that is, independent get and set accessors with an
+Semi-affordance accessors--that is, independent get and set accessors with an
 explicit set accessor.
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2006, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
